porestructure — Translate Toolkit 3.5.2 documentation

# porestructure

porestructure takes the PO files output by poconflicts (a flat structure), and recreates the directory structure according to the poconflict location comments found in each PO message. After being restructured, the messages in the resulting directory structure can be merged back using pomerge.

Since poconflicts adds conflicting messages, from many different PO files, into a single PO file, the original structure of the files and directories are lost and the new PO files are output to a single directory. The original structure information is left in “(pofilter)” comments for each PO element.

## Usage

    porestructure [options] <conflicts> <po>

Where:

<conflicts> | is a directory containing one the corrected output from poconflict
<po> | is an output directory to write the restructured files to

Options:

`--version`

  show program’s version number and exit

`-h, --help`

  show this help message and exit

`--manpage`

  output a manpage based on the help

`--progress=PROGRESS`

  show progress as: dots, none, bar, names, verbose

`--errorlevel=ERRORLEVEL`

  show errorlevel as: none, message, exception, traceback

`-i INPUT, --input=INPUT`

  read from INPUT in po format

`-x EXCLUDE, --exclude=EXCLUDE`

  exclude names matching EXCLUDE from input paths

`-o OUTPUT, --output=OUTPUT`

  write to OUTPUT in po format

## Examples

The documentation for poconflicts has Examples for the complete process using poconflict, porestructure, and pomerge.